@@ -48,7 +48,7 @@ var config = formatter.Config{
 }
 
 // VERSION is describing current version of the nmap-formatter
-const VERSION string = "3.0.2"
+const VERSION string = "3.1.0"
 
 var workflow formatter.Workflow
 
@@ -115,6 +115,9 @@ func init() {
 	// Pretty-print json
 	rootCmd.Flags().BoolVar(&config.OutputOptions.JSONOptions.PrettyPrint, "json-pretty", true, "--json-pretty=false (pretty prints JSON output)")
 
+	// Snake case json keys
+	rootCmd.Flags().BoolVar(&config.OutputOptions.JSONOptions.SnakeCase, "json-snake-case", false, "--json-snake-case=true (converts JSON keys to snake_case)")
+
 	// Configs related to SQLite
 	rootCmd.Flags().StringVar(&config.OutputOptions.SqliteOutputOptions.DSN, "sqlite-dsn", "nmap.sqlite", "--sqlite-dsn nmap.sqlite")
 	rootCmd.Flags().StringVar(&config.OutputOptions.SqliteOutputOptions.ScanIdentifier, "scan-id", "", "--scan-id abc123")
@@ -181,10 +184,14 @@ func run(cmd *cobra.Command, args []string) error {
 	}
 
 	if config.Writer != nil {
-		config.Writer.Close()
+		if closeErr := config.Writer.Close(); closeErr != nil {
+			log.Printf("Error closing writer: %v", closeErr)
+		}
 	}
 	if config.InputFileConfig.Source != nil {
-		config.InputFileConfig.Source.Close()
+		if closeErr := config.InputFileConfig.Source.Close(); closeErr != nil {
+			log.Printf("Error closing input source: %v", closeErr)
+		}
 	}
 
 	return nil
