@@ -19,11 +19,11 @@ func (f *CSVFormatter) Format(td *TemplateData, templateContent string) (err err
 func (f *CSVFormatter) convert(td *TemplateData) (data [][]string) {
 	data = append(data, []string{"IP", "Port", "Protocol", "State", "Service", "Reason", "Product", "Version", "Extra info"})
 	for i := range td.NMAPRun.Host {
-		var host *Host = &td.NMAPRun.Host[i]
+		host := &td.NMAPRun.Host[i]
 		address := fmt.Sprintf("%s (%s)", host.JoinedAddresses("/"), host.Status.State)
 		data = append(data, []string{address, "", "", "", "", "", "", "", ""})
 		for j := range host.Port {
-			var port *Port = &host.Port[j]
+			port := &host.Port[j]
 			data = append(
 				data,
 				[]string{
